@@ -1,7 +1,7 @@
 # ABSTRACT: take structured address data and format it according to the various global/country rules
 
 package Geo::Address::Formatter;
-$Geo::Address::Formatter::VERSION = '1.41';
+$Geo::Address::Formatter::VERSION = '1.42';
 use strict;
 use warnings;
 
@@ -180,8 +180,24 @@ sub _postformat {
     # do any country specific rules
     foreach my $ra_fromto ( @$raa_rules ){
         try {
-            my $regexp = qr/$ra_fromto->[0]/;
-            $text =~ s/$regexp/$ra_fromto->[1]/;
+            my $regexp = qr/$ra_fromto->[0]/;	    
+	    #say STDERR 'text: ' . $text;
+	    #say STDERR 're: ' . $regexp;
+            my $replacement = $ra_fromto->[1];
+
+            # ultra hack to do substitution
+            # limited to $1 and $2, should really be a while loop
+            # doing every substitution
+
+            if ($replacement =~ m/\$\d/){
+                if ($text =~ m/$regexp/){
+                    my $tmp1 = $1;
+                    my $tmp2 = $2;
+		    $replacement =~ s/\$1/$tmp1/;
+		    $replacement =~ s/\$2/$tmp2/;
+                }
+            }
+	    $text =~ s/$regexp/$replacement/;
         }
         catch {
             warn "invalid replacement: " . join(', ', @$ra_fromto)
@@ -354,7 +370,7 @@ Geo::Address::Formatter - take structured address data and format it according t
 
 =head1 VERSION
 
-version 1.41
+version 1.42
 
 =head1 SYNOPSIS
 
